Page 68 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 68

Home

    on exportation; bounties to raise up a losing trade, and
    taxes to pull down a remunerative one; this branch of
    industry forbidden, and that branch of industry
    encouraged; one article of commerce must not be grown,
    because it was grown in the colonies, another article
    might be grown and bought, but not sold again, while a
    third article might be bought and sold, but not leave the
    country. Then, too, we find laws to regulate wages; laws
    to regulate prices; laws to regulate profits; laws to
    regulate the interest of money; custom-house

    ea wed sa oad

    of

    regulate the interest of money; custom-house
    arrangements of the most vexatious kind, aided by a
    complicated scheme, which was called the sliding scale,
    — a scheme of such perverse ingenuity, that the duties
    constantly varied on the same article, and no man could
    calculate beforehand what he would have to pay. . . . The
    tolls were so onerous, as to double and often quadruple
    the cost of production.°

    Under the care of the state, planning for their
    welfare, conditions were such that only smuggling kept
    the French people from starving to death. The American
    Colonists knew about planned economy. They wanted

    When the members of the Continental Congress were
    finally able to get down to the business of establishing
    the new government, they had a clean slate. The problem
    was what to write on that slate. Probably no one knew
    that they would eventually produce what would be
    heralded as one of the greatest documents ever penned
    by mortal men — The United States Constitution.

    63

    The American Republic

    of industry

    custom-house

    none of it.